@@ -112,11 +112,15 @@ class ExtensionDescriptor(object):
         """
 
     def get_required_extensions(self):
-        """Returns a list of extensions to be processed before this one."""
+        """Return list of extensions required for processing this descriptor.
+
+        Without these extensions present in a neutron deployment, the
+        introduced extension cannot load or function properly.
+        """
         return []
 
     def get_optional_extensions(self):
-        """Returns a list of extensions to be processed before this one.
+        """Returns a list of optionally required extensions.
 
         Unlike get_required_extensions. This will not fail the loading of
         the extension if one of these extensions is not present. This is
@@ -232,3 +236,15 @@ class APIExtensionDescriptor(ExtensionDescriptor):
         """Returns the API definition's optional extensions."""
         self._assert_api_definition('OPTIONAL_EXTENSIONS')
         return self.api_definition.OPTIONAL_EXTENSIONS
+
+    def update_attributes_map(self, attributes, extension_attrs_map=None):
+        """Update attributes map for this extension.
+
+        Behaves like ExtensionDescriptor.update_attributes_map(), but
+        if extension_attrs_map is not given the extension's API
+        definition RESOURCE_ATTRIBUTE_MAP is used.
+        """
+        if extension_attrs_map is None:
+            extension_attrs_map = self.get_extended_resources('2.0')
+        super(APIExtensionDescriptor, self).update_attributes_map(
+            attributes, extension_attrs_map=extension_attrs_map)
